#
# spec file for package xosd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libxosd2
Name:           xosd
Version:        2.2.14
Release:        1.5
Summary:        X On-Screen Display library
License:        GPL-2.0-or-later
URL:            https://sourceforge.net/projects/libxosd
Source:         http://sourceforge.net/projects/libxosd/files/libxosd/xosd-%{version}/%{name}-%{version}.tar.gz
Patch0:         xosd.patch
Patch1:         xosd-2.2.14-config.patch
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)

%description
A tool for displaying a TV-like on-screen display in X

%package -n %{libname}
Summary:        Library for X On-Screen Display
Group:          System/Libraries
Conflicts:      xosd < %{version}-%{release}

%description -n %{libname}
A library for displaying a TV-like on-screen display in X

%package devel
Summary:        X On-Screen Display library development files
Group:          Development/Libraries/X11
Requires:       xosd = %{version}

%description devel
Development headers and libraries for xosd package

%prep
%autosetup -p1

%build
%configure \
  --disable-silent-rules \
  --disable-gtktest \
  --disable-gdk_pixbuftest \
  --disable-beep_media_player_plugin \
  --disable-static \
  --disable-new-plugin \
  --disable-old-plugin \
  --enable-xinerama
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_mandir}/man1/osd_cat.1%{?ext_man}
%license COPYING
%doc AUTHORS ChangeLog README
%{_datadir}/%{name}
%{_bindir}/osd_cat

%files -n %{libname}
%{_libdir}/libxosd.so.*

%files devel
%{_mandir}/man3/xosd*3%{?ext_man}
%{_libdir}/libxosd.so
%{_includedir}/xosd.h
%{_bindir}/xosd-config
%{_datadir}/aclocal/libxosd.m4
%{_mandir}/man1/xosd-config.1%{?ext_man}

%changelog
* Tue Mar 28 2023 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Fri Jul 28 2017 tchvatal@suse.com
- Cleanup with spec-cleaner
- Use configure switches from Fedora and Debian
- Split out library to specific subpackage
* Fri Jun 19 2015 mpluskal@suse.com
- Update project url
- Use url for source
- Cleanup spec file with spec-cleaner
- Clenaup dependencies
* Sat Nov  1 2014 crrodriguez@opensuse.org
- Switch to individual pkgconfig() build requires
  instead of using metapackage xorg-x11-devel
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov 24 2010 ro@suse.de
- xft-config is gone
* Thu Jan  7 2010 vuntz@opensuse.org
- Remove unneeded gtk1-compat-devel BuildRequires: we don't build
  the xmms plugin.
- Move the API man pages to devel package.
* Sun Mar  1 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package dependencies
- fix xosd-config to not bloat other packages with bogus dependencies
* Sat Jan 26 2008 bwalle@suse.de
- update to 2.4.14
  o 2.2.13 -> 2.2.24
    + Timeout Bigfix Patch
    + Documentation Patch
    + Beep Plugin Security Patch
  o 2.2.12 -> 2.2.13
    + buffer overflow patch
    + timeout patch
    + x window select patch
    + x event patch
    + synchronous update patch
    + debug patch
    + configure.ac patch
    + beep media player plugin
    + configure patch so xosd compiles when beep media player not
    installed
* Fri Nov 30 2007 lmichnovic@suse.cz
- added gcc-c++ to BuildRequires
* Thu Aug 30 2007 lmichnovic@suse.cz
- fixed rpmlint warnings: bziped archive, fixed files permissions
- specifying X.org headers dir and library dir
- fixed Requires for devel package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 19 2005 lmichnovic@suse.cz
- xosd-xmms canceled
- build as gtk2 aplication
- changed needforbuild (xorg <-> x11)
* Tue Nov 30 2004 seife@suse.de
- update to version 2.2.12
* Mon Nov  8 2004 ro@suse.de
- cleaned neededforbuild
* Fri Aug 27 2004 seife@suse.de
- update to version 2.2.10
* Tue Aug 24 2004 seife@suse.de
- xmms -> xmms-lib
* Mon Jul  5 2004 seife@suse.de
- update to version 2.2.8
* Tue Feb 17 2004 seife@suse.de
- aclocal quoting fixed
* Sat Feb 14 2004 kukuk@suse.de
- Fix build on lib64 architecures
- Fix ldconfig post/postun section
* Fri Feb 13 2004 seife@suse.de
- initial checkin
